@@ -22,15 +22,14 @@
  *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef _GMIC_QT_DIALOGSETTINGS_H_
-#define _GMIC_QT_DIALOGSETTINGS_H_
+#ifndef GMIC_QT_DIALOGSETTINGS_H
+#define GMIC_QT_DIALOGSETTINGS_H
 
 #include <QColor>
 #include <QDialog>
 #include <QIcon>
 #include "MainWindow.h"
-#include "gmic_qt.h"
-
+#include "GmicQt.h"
 class QCloseEvent;
 class QSettings;
 
@@ -39,29 +38,36 @@ namespace Ui
 class DialogSettings;
 }
 
+namespace GmicQt
+{
+
 class DialogSettings : public QDialog {
   Q_OBJECT
 
 public:
-  explicit DialogSettings(QWidget * parent = 0);
-  ~DialogSettings();
+  explicit DialogSettings(QWidget * parent = nullptr);
+  ~DialogSettings() override;
   static MainWindow::PreviewPosition previewPosition();
   static bool logosAreVisible();
   static bool darkThemeEnabled();
   static QString languageCode();
   static bool nativeColorDialogs();
   static void saveSettings(QSettings &);
-  static void loadSettings();
+  static void loadSettings(UserInterfaceMode userInterfaceMode);
   static bool previewZoomAlwaysEnabled();
+  static bool notifyFailedStartupUpdate();
   static const QColor CheckBoxTextColor;
   static const QColor CheckBoxBaseColor;
   static QColor UnselectedFilterTextColor;
   static QString FolderParameterDefaultValue;
   static QString FileParameterDefaultPath;
   static int previewTimeout();
-  static GmicQt::OutputMessageMode outputMessageMode();
+  static OutputMessageMode outputMessageMode();
   static QIcon AddIcon;
   static QIcon RemoveIcon;
+  static QString GroupSeparator;
+  static QString DecimalPoint;
+  static QString NegativeSign;
 
 public slots:
   void onRadioLeftPreviewToggled(bool);
@@ -76,8 +82,10 @@ public slots:
   void onPreviewTimeoutChange(int);
   void onOutputMessageModeChanged(int);
   void onPreviewZoomToggled(bool);
+  void onNotifyStartupUpdateFailedToggle(bool);
 
 private:
+  static void removeObsoleteKeys(QSettings &);
   Ui::DialogSettings * ui;
   static bool _darkThemeEnabled;
   static QString _languageCode;
@@ -86,8 +94,11 @@ private:
   static int _updatePeriodicity;
   static bool _logosAreVisible;
   static int _previewTimeout;
-  static GmicQt::OutputMessageMode _outputMessageMode;
+  static OutputMessageMode _outputMessageMode;
   static bool _previewZoomAlwaysEnabled;
+  static bool _notifyFailedStartupUpdate;
 };
 
-#endif // _GMIC_QT_DIALOGSETTINGS_H_
+} // namespace GmicQt
+
+#endif // GMIC_QT_DIALOGSETTINGS_H
