@@ -30,13 +30,18 @@
 class QCheckBox;
 class QLabel;
 
+namespace GmicQt
+{
+
 class BoolParameter : public AbstractParameter {
   Q_OBJECT
 public:
   BoolParameter(QObject * parent = nullptr);
   ~BoolParameter() override;
+  virtual int size() const override;
   bool addTo(QWidget *, int row) override;
-  QString textValue() const override;
+  QString value() const override;
+  QString defaultValue() const override;
   void setValue(const QString & value) override;
   void reset() override;
   bool initFromText(const char * text, int & textLength) override;
@@ -54,4 +59,6 @@ private:
   bool _connected;
 };
 
+} // namespace GmicQt
+
 #endif // GMIC_QT_BOOLPARAMETER_H
