@@ -32,13 +32,21 @@
 #include "FilterTextTranslator.h"
 #include "HtmlTranslator.h"
 
-ButtonParameter::ButtonParameter(QObject * parent) : AbstractParameter(parent, true), _value(false), _pushButton(nullptr), _alignment(Qt::AlignHCenter) {}
+namespace GmicQt
+{
+
+ButtonParameter::ButtonParameter(QObject * parent) : AbstractParameter(parent), _value(false), _pushButton(nullptr), _alignment(Qt::AlignHCenter) {}
 
 ButtonParameter::~ButtonParameter()
 {
   delete _pushButton;
 }
 
+int ButtonParameter::size() const
+{
+  return 1;
+}
+
 bool ButtonParameter::addTo(QWidget * widget, int row)
 {
   _grid = dynamic_cast<QGridLayout *>(widget->layout());
@@ -52,11 +60,16 @@ bool ButtonParameter::addTo(QWidget * widget, int row)
   return true;
 }
 
-QString ButtonParameter::textValue() const
+QString ButtonParameter::value() const
 {
   return _value ? QString("1") : QString("0");
 }
 
+QString ButtonParameter::defaultValue() const
+{
+  return QString("0");
+}
+
 void ButtonParameter::setValue(const QString & s)
 {
   _value = (s == "1");
@@ -96,3 +109,5 @@ bool ButtonParameter::initFromText(const char * text, int & textLength)
   }
   return true;
 }
+
+} // namespace GmicQt
