@@ -26,9 +26,19 @@
 #include <QString>
 #include <QStringList>
 #include "Common.h"
+#include "FilterTextTranslator.h"
 #include "HtmlTranslator.h"
+#include "Misc.h"
 
-ConstParameter::ConstParameter(QObject * parent) : AbstractParameter(parent, true) {}
+namespace GmicQt
+{
+
+ConstParameter::ConstParameter(QObject * parent) : AbstractParameter(parent) {}
+
+int ConstParameter::size() const
+{
+  return 1;
+}
 
 ConstParameter::~ConstParameter() = default;
 
@@ -37,11 +47,21 @@ bool ConstParameter::addTo(QWidget *, int)
   return false;
 }
 
-QString ConstParameter::textValue() const
+bool ConstParameter::isQuoted() const
+{
+  return true;
+}
+
+QString ConstParameter::value() const
 {
   return _value;
 }
 
+QString ConstParameter::defaultValue() const
+{
+  return _default;
+}
+
 void ConstParameter::setValue(const QString & value)
 {
   _value = value;
@@ -58,7 +78,9 @@ bool ConstParameter::initFromText(const char * text, int & textLength)
   if (list.isEmpty()) {
     return false;
   }
-  _name = HtmlTranslator::html2txt(list[0]);
-  _value = _default = list[1];
+  _name = HtmlTranslator::html2txt(FilterTextTranslator::translate(list[0]));
+  _value = _default = unescaped(unquoted(list[1]));
   return true;
 }
+
+} // namespace GmicQt
