@@ -39,7 +39,10 @@
 #include "HtmlTranslator.h"
 #include "Logger.h"
 
-FloatParameter::FloatParameter(QObject * parent) : AbstractParameter(parent, true), _min(0), _max(0), _default(0), _value(0), _label(nullptr), _slider(nullptr), _spinBox(nullptr)
+namespace GmicQt
+{
+
+FloatParameter::FloatParameter(QObject * parent) : AbstractParameter(parent), _min(0), _max(0), _default(0), _value(0), _label(nullptr), _slider(nullptr), _spinBox(nullptr)
 {
   _timerId = 0;
   _connected = false;
@@ -52,6 +55,11 @@ FloatParameter::~FloatParameter()
   delete _label;
 }
 
+int FloatParameter::size() const
+{
+  return 1;
+}
+
 bool FloatParameter::addTo(QWidget * widget, int row)
 {
   _grid = dynamic_cast<QGridLayout *>(widget->layout());
@@ -79,10 +87,13 @@ bool FloatParameter::addTo(QWidget * widget, int row)
   _grid->addWidget(_spinBox, row, 2, 1, 1);
 
   connectSliderSpinBox();
+
+  connect(_spinBox, &CustomDoubleSpinBox::editingFinished, [this]() { notifyIfRelevant(); });
+
   return true;
 }
 
-QString FloatParameter::textValue() const
+QString FloatParameter::value() const
 {
   QLocale currentLocale;
   QLocale::setDefault(QLocale::c());
@@ -91,6 +102,15 @@ QString FloatParameter::textValue() const
   return value;
 }
 
+QString FloatParameter::defaultValue() const
+{
+  QLocale currentLocale;
+  QLocale::setDefault(QLocale::c());
+  QString value = QString("%1").arg(static_cast<double>(_default));
+  QLocale::setDefault(currentLocale);
+  return value;
+}
+
 void FloatParameter::setValue(const QString & value)
 {
   bool ok = true;
@@ -141,7 +161,9 @@ void FloatParameter::timerEvent(QTimerEvent * event)
 {
   killTimer(event->timerId());
   _timerId = 0;
-  notifyIfRelevant();
+  if (not _spinBox->unfinishedKeyboardEditing()) {
+    notifyIfRelevant();
+  }
 }
 
 void FloatParameter::onSliderMoved(int value)
@@ -154,7 +176,7 @@ void FloatParameter::onSliderMoved(int value)
 
 void FloatParameter::onSliderValueChanged(int value)
 {
-  float fValue = _min + (float(value) / static_cast<float>(SLIDER_MAX_RANGE)) * (_max - _min);
+  const float fValue = _min + (float(value) / static_cast<float>(SLIDER_MAX_RANGE)) * (_max - _min);
   if (fValue != _value) {
     _spinBox->setValue(_value = fValue);
   }
@@ -169,7 +191,11 @@ void FloatParameter::onSpinBoxChanged(double x)
   if (_timerId) {
     killTimer(_timerId);
   }
-  _timerId = startTimer(UPDATE_DELAY);
+  if (_spinBox->unfinishedKeyboardEditing()) {
+    _timerId = 0;
+  } else {
+    _timerId = startTimer(UPDATE_DELAY);
+  }
 }
 
 void FloatParameter::connectSliderSpinBox()
@@ -192,3 +218,5 @@ void FloatParameter::disconnectSliderSpinBox()
   _spinBox->disconnect(this);
   _connected = false;
 }
+
+} // namespace GmicQt
