@@ -27,23 +27,29 @@
 
 #include <QString>
 #include "AbstractParameter.h"
-class CustomDoubleSpinBox;
 class QSlider;
 class QLabel;
 
+namespace GmicQt
+{
+class CustomDoubleSpinBox;
+
 class FloatParameter : public AbstractParameter {
   Q_OBJECT
 public:
   FloatParameter(QObject * parent = nullptr);
   ~FloatParameter() override;
+  virtual int size() const override;
   bool addTo(QWidget *, int row) override;
-  QString textValue() const override;
+  QString value() const override;
+  QString defaultValue() const override;
   void setValue(const QString & value) override;
   void reset() override;
   bool initFromText(const char * text, int & textLength) override;
 
 protected:
   void timerEvent(QTimerEvent * event) override;
+
 public slots:
   void onSliderMoved(int);
   void onSliderValueChanged(int);
@@ -66,4 +72,6 @@ private:
   bool _connected;
 };
 
+} // namespace GmicQt
+
 #endif // GMIC_QT_FLOATPARAMETER_H
