@@ -34,10 +34,14 @@
 #include <QWidget>
 #include "Common.h"
 #include "DialogSettings.h"
+#include "FilterTextTranslator.h"
 #include "HtmlTranslator.h"
 #include "IconLoader.h"
 
-FolderParameter::FolderParameter(QObject * parent) : AbstractParameter(parent, true), _label(nullptr), _button(nullptr) {}
+namespace GmicQt
+{
+
+FolderParameter::FolderParameter(QObject * parent) : AbstractParameter(parent), _label(nullptr), _button(nullptr) {}
 
 FolderParameter::~FolderParameter()
 {
@@ -45,6 +49,11 @@ FolderParameter::~FolderParameter()
   delete _button;
 }
 
+int FolderParameter::size() const
+{
+  return 1;
+}
+
 bool FolderParameter::addTo(QWidget * widget, int row)
 {
   _grid = dynamic_cast<QGridLayout *>(widget->layout());
@@ -62,16 +71,16 @@ bool FolderParameter::addTo(QWidget * widget, int row)
   return true;
 }
 
-QString FolderParameter::textValue() const
-{
-  return QString("\"%1\"").arg(_value);
-}
-
-QString FolderParameter::unquotedTextValue() const
+QString FolderParameter::value() const
 {
   return _value;
 }
 
+QString FolderParameter::defaultValue() const
+{
+  return _default;
+}
+
 void FolderParameter::setValue(const QString & value)
 {
   _value = value;
@@ -100,7 +109,7 @@ bool FolderParameter::initFromText(const char * text, int & textLength)
   if (list.isEmpty()) {
     return false;
   }
-  _name = HtmlTranslator::html2txt(list[0]);
+  _name = HtmlTranslator::html2txt(FilterTextTranslator::translate(list[0]));
   QRegExp re("^\".*\"$");
   if (re.exactMatch(list[1])) {
     list[1].chop(1);
@@ -132,3 +141,5 @@ void FolderParameter::onButtonPressed()
   }
   notifyIfRelevant();
 }
+
+} // namespace GmicQt
