@@ -30,15 +30,24 @@
 #include <QString>
 #include <QUrl>
 #include "Common.h"
+#include "FilterTextTranslator.h"
 #include "HtmlTranslator.h"
 
-LinkParameter::LinkParameter(QObject * parent) : AbstractParameter(parent, false), _label(nullptr), _alignment(Qt::AlignLeft) {}
+namespace GmicQt
+{
+
+LinkParameter::LinkParameter(QObject * parent) : AbstractParameter(parent), _label(nullptr), _alignment(Qt::AlignLeft) {}
 
 LinkParameter::~LinkParameter()
 {
   delete _label;
 }
 
+int LinkParameter::size() const
+{
+  return 0;
+}
+
 bool LinkParameter::addTo(QWidget * widget, int row)
 {
   _grid = dynamic_cast<QGridLayout *>(widget->layout());
@@ -54,7 +63,12 @@ bool LinkParameter::addTo(QWidget * widget, int row)
   return true;
 }
 
-QString LinkParameter::textValue() const
+QString LinkParameter::value() const
+{
+  return QString();
+}
+
+QString LinkParameter::defaultValue() const
 {
   return QString();
 }
@@ -91,7 +105,7 @@ bool LinkParameter::initFromText(const char * text, int & textLength)
 
   if (values.size() == 2) {
     _text = values[0].trimmed().remove(QRegExp("^\"")).remove(QRegExp("\"$"));
-    _text = HtmlTranslator::html2txt(_text);
+    _text = HtmlTranslator::html2txt(FilterTextTranslator::translate(_text));
     values.pop_front();
   }
   if (values.size() == 1) {
@@ -110,3 +124,5 @@ void LinkParameter::onLinkActivated(const QString & link)
 {
   QDesktopServices::openUrl(QUrl(link));
 }
+
+} // namespace GmicQt
