@@ -29,6 +29,7 @@
 #include <QIcon>
 #include <QLabel>
 #include <QLineEdit>
+#include <QRegularExpression>
 #include <QTextEdit>
 #include <QWidget>
 #include "Common.h"
@@ -37,8 +38,12 @@
 #include "FilterTextTranslator.h"
 #include "HtmlTranslator.h"
 #include "IconLoader.h"
+#include "Misc.h"
 
-TextParameter::TextParameter(QObject * parent) : AbstractParameter(parent, true), _label(nullptr), _lineEdit(nullptr), _textEdit(nullptr), _multiline(false), _connected(false)
+namespace GmicQt
+{
+
+TextParameter::TextParameter(QObject * parent) : AbstractParameter(parent), _label(nullptr), _lineEdit(nullptr), _textEdit(nullptr), _multiline(false), _connected(false)
 {
   _updateAction = nullptr;
 }
@@ -50,6 +55,11 @@ TextParameter::~TextParameter()
   delete _label;
 }
 
+int TextParameter::size() const
+{
+  return 1;
+}
+
 bool TextParameter::addTo(QWidget * widget, int row)
 {
   _grid = dynamic_cast<QGridLayout *>(widget->layout());
@@ -76,22 +86,20 @@ bool TextParameter::addTo(QWidget * widget, int row)
   return true;
 }
 
-QString TextParameter::textValue() const
-{
-  QString text = _multiline ? _textEdit->text() : _lineEdit->text();
-  text.replace(QChar('"'), QString("\\\""));
-  return QString("\"%1\"").arg(text);
-}
-
-QString TextParameter::unquotedTextValue() const
+QString TextParameter::value() const
 {
   return _multiline ? _textEdit->text() : _lineEdit->text();
 }
 
+QString TextParameter::defaultValue() const
+{
+  return _default;
+}
+
 void TextParameter::setValue(const QString & value)
 {
   _value = value;
-  if (_multiline && _textEdit) {
+  if (_textEdit) {
     disconnectEditor();
     _textEdit->setText(_value);
     connectEditor();
@@ -104,9 +112,9 @@ void TextParameter::setValue(const QString & value)
 
 void TextParameter::reset()
 {
-  if (_multiline) {
+  if (_textEdit) {
     _textEdit->setText(_default);
-  } else {
+  } else if (_lineEdit) {
     _lineEdit->setText(_default);
   }
   _value = _default;
@@ -121,15 +129,13 @@ bool TextParameter::initFromText(const char * text, int & textLength)
   _name = HtmlTranslator::html2txt(FilterTextTranslator::translate(list[0]));
   QString value = list[1];
   _multiline = false;
-  QRegExp re("^\\s*(0|1)\\s*,");
-  if (value.contains(re) && re.matchedLength() > 0) {
-    _multiline = (re.cap(1).toInt() == 1);
+  QRegularExpression re("^\\s*(0|1)\\s*,");
+  auto match = re.match(value);
+  if (match.hasMatch()) {
+    _multiline = (match.captured(1).toInt() == 1);
     value.replace(re, "");
   }
-  value = value.trimmed().remove(QRegExp("^\"")).remove(QRegExp("\"$"));
-  value.replace(QString("\\\\"), QString("\\"));
-  value.replace(QString("\\n"), QString("\n"));
-  _value = _default = value;
+  _value = _default = unescaped(unquoted(value));
   return true;
 }
 
@@ -148,9 +154,9 @@ void TextParameter::connectEditor()
   if (_connected) {
     return;
   }
-  if (_multiline) {
+  if (_textEdit) {
     connect(_textEdit, SIGNAL(valueChanged()), this, SLOT(onValueChanged()));
-  } else {
+  } else if (_lineEdit) {
     connect(_lineEdit, SIGNAL(editingFinished()), this, SLOT(onValueChanged()));
 #if QT_VERSION_GTE(5, 2, 0)
     connect(_updateAction, SIGNAL(triggered(bool)), this, SLOT(onValueChanged()));
@@ -164,9 +170,9 @@ void TextParameter::disconnectEditor()
   if (!_connected) {
     return;
   }
-  if (_multiline) {
+  if (_textEdit) {
     _textEdit->disconnect(this);
-  } else {
+  } else if (_lineEdit) {
     _lineEdit->disconnect(this);
 #if QT_VERSION_GTE(5, 2, 0)
     _updateAction->disconnect(this);
@@ -174,3 +180,5 @@ void TextParameter::disconnectEditor()
   }
   _connected = false;
 }
+
+} // namespace GmicQt
