@@ -22,8 +22,8 @@
  *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef _GMIC_QT_FILTERSVIEW_H_
-#define _GMIC_QT_FILTERSVIEW_H_
+#ifndef GMIC_QT_FILTERSVIEW_H
+#define GMIC_QT_FILTERSVIEW_H
 
 #include <QAction>
 #include <QList>
@@ -32,17 +32,20 @@
 #include <QStandardItemModel>
 #include <QString>
 #include <QWidget>
+class QSettings;
+class QEvent;
 
 namespace Ui
 {
 class FiltersView;
 }
 
+namespace GmicQt
+{
+
 class FilterTreeFolder;
 class FilterTreeItem;
 class FilterTreeAbstractItem;
-class QSettings;
-class QEvent;
 
 class FiltersView : public QWidget {
   Q_OBJECT
@@ -130,4 +133,6 @@ private:
   QMenu * _filterContextMenu;
 };
 
-#endif // _GMIC_QT_FILTERSVIEW_H_
+} // namespace GmicQt
+
+#endif // GMIC_QT_FILTERSVIEW_H
