@@ -29,7 +29,7 @@
 #include <QRegExp>
 #include <QString>
 #include "Common.h"
-#include "Host/host.h"
+#include "Host/GmicQtHost.h"
 #include "gmic.h"
 
 #ifdef _IS_WINDOWS_
@@ -42,9 +42,10 @@
 
 namespace GmicQt
 {
-const QString & path_rc(bool create)
+
+const QString & gmicConfigPath(bool create)
 {
-  QString qpath = QString::fromLocal8Bit(gmic::path_rc());
+  QString qpath = QString::fromUtf8(gmic::path_rc());
   QFileInfo dir(qpath);
   static QString result;
   if (dir.isDir()) {
@@ -54,7 +55,7 @@ const QString & path_rc(bool create)
   if (!create || !gmic::init_rc()) {
     result.clear();
   } else {
-    result = QString::fromLocal8Bit(gmic::path_rc());
+    result = QString::fromUtf8(gmic::path_rc());
   }
   return result;
 }
@@ -94,10 +95,10 @@ const QString & pluginFullName()
   static QString result;
   if (result.isEmpty()) {
     result = QString("G'MIC-Qt %1- %2 %3 bits - %4" BETA_SUFFIX)
-                 .arg(GmicQt::HostApplicationName.isEmpty() ? QString() : QString("for %1 ").arg(GmicQt::HostApplicationName))
+                 .arg(GmicQtHost::ApplicationName.isEmpty() ? QString() : QString("for %1 ").arg(GmicQtHost::ApplicationName))
                  .arg(cimg_library::cimg::stros())
                  .arg(sizeof(void *) == 8 ? 64 : 32)
-                 .arg(GmicQt::gmicVersionString());
+                 .arg(gmicVersionString());
   }
   return result;
 }
@@ -106,77 +107,9 @@ const QString & pluginCodeName()
 {
   static QString result;
   if (result.isEmpty()) {
-    result = GmicQt::HostApplicationName.isEmpty() ? QString("gmic_qt") : QString("gmic_%1_qt").arg(QString(GmicQt::HostApplicationShortname).toLower());
+    result = GmicQtHost::ApplicationName.isEmpty() ? QString("gmic_qt") : QString("gmic_%1_qt").arg(QString(GmicQtHost::ApplicationShortname).toLower());
   }
   return result;
 }
 
-const char * commandFromOutputMessageMode(OutputMessageMode mode)
-{
-  switch (mode) {
-  case Quiet:
-  case VerboseConsole:
-  case VerboseLogFile:
-  case UnspecifiedOutputMessageMode:
-    return "";
-  case VeryVerboseConsole:
-  case VeryVerboseLogFile:
-    return "v 3";
-  case DebugConsole:
-  case DebugLogFile:
-    return "debug";
-  }
-  return "";
-}
-
-void downcaseCommandTitle(QString & title)
-{
-  QMap<int, QString> acronyms;
-  // Acronyms
-  QRegExp re("([A-Z0-9]{2,255})");
-  int index = 0;
-  while ((index = re.indexIn(title, index)) != -1) {
-    QString pattern = re.cap(0);
-    acronyms[index] = pattern;
-    index += pattern.length();
-  }
-
-  // 3D
-  re.setPattern("([1-9])[dD] ");
-  if ((index = re.indexIn(title, 0)) != -1) {
-    acronyms[index] = re.cap(1) + "d ";
-  }
-
-  // B&amp;W
-  re.setPattern("(B&amp;W|[ \\[]Lab|[ \\[]YCbCr)");
-  index = 0;
-  while ((index = re.indexIn(title, index)) != -1) {
-    acronyms[index] = re.cap(1);
-    index += re.cap(1).length();
-  }
-
-  // Uppercase letter in last position, after a space
-  re.setPattern(" ([A-Z])$");
-  if ((index = re.indexIn(title, 0)) != -1) {
-    acronyms[index] = re.cap(0);
-  }
-  title = title.toLower();
-  QMap<int, QString>::const_iterator it = acronyms.cbegin();
-  while (it != acronyms.cend()) {
-    title.replace(it.key(), it.value().length(), it.value());
-    ++it;
-  }
-  title[0] = title[0].toUpper();
-}
-
-void appendWithSpace(QString & str, const QString & other)
-{
-  if (str.isEmpty() || other.isEmpty()) {
-    str += other;
-    return;
-  }
-  str += QChar(' ');
-  str += other;
-}
-
 } // namespace GmicQt
