@@ -22,18 +22,20 @@
  *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef _GMIC_QT_PREVIEWWIDGET_H_
-#define _GMIC_QT_PREVIEWWIDGET_H_
+#ifndef GMIC_QT_PREVIEWWIDGET_H
+#define GMIC_QT_PREVIEWWIDGET_H
 
 #include <QFocusEvent>
 #include <QImage>
 #include <QMutex>
 #include <QPixmap>
+#include <QPointF>
 #include <QRect>
+#include <QRectF>
 #include <QSize>
 #include <QWidget>
 #include <memory>
-#include "Host/host.h"
+#include "Host/GmicQtHost.h"
 #include "KeypointList.h"
 #include "ZoomConstraint.h"
 
@@ -43,12 +45,15 @@ template <typename T> struct CImgList;
 template <typename T> struct CImg;
 } // namespace cimg_library
 
+namespace GmicQt
+{
+
 class PreviewWidget : public QWidget {
   Q_OBJECT
 
 public:
-  explicit PreviewWidget(QWidget * parent = 0);
-  ~PreviewWidget();
+  explicit PreviewWidget(QWidget * parent = nullptr);
+  ~PreviewWidget() override;
   void setFullImageSize(const QSize &);
   void updateFullImageSizeIfDifferent(const QSize &);
   void normalizedVisibleRect(double & x, double & y, double & width, double & height) const;
@@ -71,15 +76,15 @@ public:
   const KeypointList & keypoints() const;
   void setKeypoints(const KeypointList &);
 
+  void setZoomConstraint(const ZoomConstraint & constraint);
+  ZoomConstraint zoomConstraint() const;
+
   enum KeypointMotionFlags
   {
     KeypointBurstEvent = 1,
     KeypointMouseReleaseEvent = 2
   };
 
-  void setZoomConstraint(const ZoomConstraint & constraint);
-  ZoomConstraint zoomConstraint() const;
-
 protected:
   void resizeEvent(QResizeEvent *) override;
   void timerEvent(QTimerEvent *) override;
@@ -112,7 +117,7 @@ public slots:
    * @brief setPreviewFactor
    * @param filterFactor
    * @param reset If true, zoomFactor is set to "Full Image" if
-   *              filterFactor is GmicQt::PreviewFactorAny
+   *              filterFactor is PreviewFactorAny
    */
   void setPreviewFactor(float filterFactor, bool reset);
   void displayOriginalImage();
@@ -145,8 +150,8 @@ private:
   ZoomConstraint _zoomConstraint;
 
   /*
-   * (0) for a 1:1 preview
-   * (1) for previewing the whole image
+   * (0) for a 1:1 preview (PreviewFactorActualSize)
+   * (1) for previewing the whole image (PreviewFactorFullImage)
    * (2) for 1/2 image
    * GmigQt::PreviewFactorAny
    */
@@ -159,6 +164,7 @@ private:
     bool isValid() const;
     bool operator!=(const PreviewPoint &) const;
     bool operator==(const PreviewPoint &) const;
+    QPointF toPointF() const { return QPointF((qreal)x, (qreal)y); }
   };
 
   struct PreviewRect {
@@ -173,6 +179,7 @@ private:
     PreviewPoint topLeft() const;
     void moveCenter(const PreviewPoint & p);
     void moveToCenter();
+    QRectF toRectF() const { return QRectF((qreal)x, (qreal)y, (qreal)w, (qreal)h); }
     static const PreviewRect Full;
   };
 
@@ -189,7 +196,7 @@ private:
   QPixmap _transparentBackground;
   bool _paintOriginalImage;
   QSize _originalImageSize;
-  QSize _originaImageScaledSize;
+  QSize _originalImageScaledSize;
   bool _rightClickEnabled;
   QString _errorMessage;
   QString _overlayMessage;
@@ -200,4 +207,6 @@ private:
   unsigned long _keypointTimestamp;
 };
 
-#endif // _GMIC_QT_PREVIEWWIDGET_H_
+} // namespace GmicQt
+
+#endif // GMIC_QT_PREVIEWWIDGET_H
